
# q-expansion of newform 656.2.u.h, downloaded from the LMFDB on 09 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 656
weight = 2
poly_data = [4096, -12800, 33216, -47528, 53273, -45930, 44829, -24314, 15482, -7928, 7811, -3168, 2935, -690, 603, -92, 60, -6, 7, -2, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[222284376971781175405101808791983273353216, -288542102373553785040547241708628971202624, 614058047195515025857577931921369362310424, -289315983891650864240355292575370254378685, 522361886529172758290698740261745274507362, -183363680932083256188411945137469908245841, 220752775222085507538200781792028183765570, -12909519551733906996311382612307156248098, 123040630847023869407597995950908987828168, -3030617300721126764538315857510978291183, 47097269563911192089255585563986952397840, 667989186285791477445941641738065184301, 9489544983170774490227223634121871442986, 138178487113344121252336926935116121113, 968578106098444550366084602921896268556, 72696037756041306660143524066692277620, 103250866148098817856312826937138160398, -10411336029074446865824724195159084451, 15461311678678653649658540561901459354, 1462795320487029758181885161474479835], 62248249974122381323764740797412088182272], [[-3749766131966828841017385704466786846400, 16353944977736196212280805404537882877688, -8463711067891530725076242835714637554319, -6271465626581259701736879507093680305376, 7820948331002369163061778182890750562881, 8003843272068094097162629257398646576568, -2460430215127019304246227948591768867546, 2862844819186380357553381255782482457868, 696462677315303774333808959672390656459, 636770397458210797083884126270298405630, 295078212369320331371425427039558304079, 404176139302467466320291469346160161700, 71856870737077713199162763168314791647, 130060012482150344340554371221773199602, -5408703600964747745242067983334961628, 15292704199713812500387057016683959842, 1935810460887869453490671832821476003, 712915810029247197247043666583415444, -192343861461341990025362540613148651, 325167014311447784470233546309121034], 7781031246765297665470592599676511022784], [[-4114713501511086705800537169357344628736, 4850641184395521157113052154963049974080, -8789363651310272187319195961842515370676, 2036511141545755153794202537987389488305, -5587960005821901588200335175866552821430, -673984717058276233081080822582918872939, -853963683241122319439508986084748334354, -531855038679951377687162389124838656230, -1236635730018953878508493833009707396844, -553913683904822819326737204516479235197, -467219795456315420851049932157266107332, -326626953460292420406976379945416133073, -88832016512243696784200461523884792646, -76275526174058251692278947369875245749, -5615975696430886875653252607579957996, -8545834161962105495259743985768510588, -1265975400928454391486207423452042794, -626094803602980017697771998025115985, -18153456429097835622102326880851646, -163895722278438599618356219630210143], 3890515623382648832735296299838255511392], [[-2309954579430374372122412574724835516416, 11550597798710113470543700300747209569280, -22536588873012085393825950876786064743296, 13204542816385905308283376380048085716193, -22940102408402190115138831931495386810642, 19966655407531441058955865053939519288165, -12689272479916146992411476741926715854202, 5447314309092908291551783220018195182602, -4676665753218709764450087894139568020128, 2776778064885758345813419218068383963979, -2015720133392274789549686089060810991080, 1139646257216591568514512082650636932911, -444488705863050020756885368002083455882, 256435001899003395853734009913077615395, -57139564764531973123007068978387684124, 24323277423262590268170765178955260172, -3739410447153032650684443146906076382, 3030222957783123838699471831986428927, -1185638833579723236912351354772994666, 438738379747923917624585072845705625], 7781031246765297665470592599676511022784], [[-71724473014156653894591627725003726203392, 155299389029502221627865017640631250919232, -179483758920315273812410919582012914579992, 84657627237972345009862346461436641830569, -240222881880867449140670342070279025696762, 39201141962052240526978834343825195255661, -45638146227395106853827428818407975702330, -8486757058491545413159715027327781244198, -45218574245401247541586443579036606361288, -8939611194021358085073637402149691744109, -19983159361866723002926082138742643167600, -6714128864785880045121298154042893438937, -4365463868009791824852123192453468419298, -1606985609261903842445008454949353957589, -360443657939778038148944059791382016476, -209511794216939830815586711178094335204, -52086268969733264201863309728306900022, -8526365593309453184095783174864486473, -4929556825824906183057251653366037714, -4020298885782804185753711584602553935], 62248249974122381323764740797412088182272], [[4331989737990193557661161004732098580480, -3804300955443893219895761403626851727360, -13599051239074747318238602343468023274095, 7103405968061270316032380249490004416416, -5935740547848709065942184154339703189615, 12592210391491141271230035297218706842432, -8264657283746477080465877752115508612842, 4054466277723930867678620963743709193044, -1694247302722642050228203558400975404709, 2389322644911107588538244726655910253726, -646959237811588609923916393113103036817, 1210715564309837865517353134638881446628, -132693088874179786950090374012736961345, 282924549345945504022943805669824185114, -27560468013161834105672486011153350060, 30097814837471591940952459803164756378, -353499570679338620464218463020654349, 2762037449626482965445287322735269156, -689169129739563568763311692156655467, 563953754743743743193948382501180546], 7781031246765297665470592599676511022784], [[324877567885243761642871502665824694132736, -385314184781324911265496275104484887727552, 566573204222457600247307172931790024311744, -248456251209453098470043403942692524685755, 620039695794167763977344196219286352894950, -131303966621348574155884076012214696473863, 153240592081998969618331178357696784597630, 11530970726321335918640156275276574289746, 123882717555660500864725493538746814911104, 16200111519810742404299297585248662046231, 52527191084755865145382663176036664667096, 13300105343433419439165316462609811466027, 11280510666539098127469998398687532879406, 3190797702081091009401395151198279823471, 981139104655518805953334984356466224884, 432642353709091205725938511202575624668, 131795229858907019243174780182339746186, 13607990083645786999335600120346420347, 14057807655625157407802648605457241678, 8338730791233715046917663163326766621], 62248249974122381323764740797412088182272], [[-153718542104650984936728929566216223432704, 179044062125899237432047171180294436101440, -237342099081262532197325675586097270448888, -42886959275576568021164040196007954511423, 41556551180374606336059081552053345291638, -287015697663250516916154854358173960857371, 92886827201398645307688023517570681447702, -100929653600628671372843782365910495589558, -5234051337389330723542326993257224373864, -60489309508305198513419085738374957818277, 3030028483657966008069076423329380935088, -27364329452993630067671297851659082122481, 1715895989223124511797982301604786765582, -6155691877654364874551027601859319252813, 438236823526816486476182984032229971972, -622818371970148812984072224422797565828, -7559997333468061454633113437481033126, -63224334196995131013195608907044368609, 13635761511706446356599331386341936350, -11485914154773034621504203432292053943], 62248249974122381323764740797412088182272], [[2498471300163090296331988851346511236480, -32293011841565186199745427373407820159792, 45870006977202346023416516782240983349884, -32254993224030738954920709407760855872769, 45720466715667055557828169363546452848430, -85507108719450779274115409919835881309973, 49580570178622406943643500996813062444002, -21307844024594018735202922958160481840874, 11493990767474005458587075186457958016628, -12255615347824956188554997432318938268387, 5388188455442858261010006089607972343436, -6418948253673593175339260294020388426367, 1258765332692638547394745728148459159150, -1577847226315511211054059825683316590971, 213260317248437637397480009789763553964, -159535082422295578218276112556919815844, 5518438334100553015899668098712452242, -15901890317266220051881079370623272431, 5078579783041184756003740990764931318, -3111703893375340383275784300242237841], 15562062493530595330941185199353022045568], [[1029196514760397871552950165658253807360, -7699018672011034217014946000494776035712, 18052352301228990341366268852174355151512, -23160032772737524447057082735937693625167, 18676938111267479524844988981748031100614, -26554700606554477837021144696942145495707, 13714195044550598085633248185623317850486, -8961730833519887989140198267902154504870, 3359719393199864311917452982843059923592, -4818218988242957445390116813860353372373, 1403933962676757838115537736573803565136, -2044966639501665416462115027422720877105, 317840522811665640004115334172850147518, -446216881199995419563886511614326914653, 51078413679070442597779976910374129076, -45644447214487251452392845348426061156, 1981633683126776270602248993628681306, -4763003892776880582274098702245138977, 1225982912948136007261262369834586942, -810634662336907159660292176410696599], 3890515623382648832735296299838255511392], [[-28808611040868510019150943503899406109696, 268389277014148069211813635923018782547328, -443061931417272356404753999910944181143136, 625370000729075043918298313663051213658711, -461312414538979252738506166092981764807422, 566938738627443898498134211239820748380243, -287555620167373869501823978389706300859798, 205108583400125916021860144645435326624134, -77517600025216247586076108689554524635360, 107896494402365428217400864384738569555805, -30986777572204944828475856266276330447640, 42781639456951275947140643005298929266937, -6883838574323302793351627312646107766566, 8945812671363888134304615003504164004709, -1034531109151867761826900001129483078404, 912859646018972771696188613045671246836, -51541849014145801784787384442742485682, 98651308000375801202313285587503599081, -24325620923268967749796650959068335750, 15581768463110536684735472842395237023], 62248249974122381323764740797412088182272], [[215137589085344662234734707459133091734528, -214252468157710729781493068967211489385856, 495364148662759554233024553927861449480664, -606379520941789047863037305944830870466391, 442030399793946633736488489746720560967542, -558328490349995394443948667935022839451987, 301494152912693440512566143705464103750118, -202863583731478217468400611206092261763366, 76506461133988604234938614513423674891784, -108928433436001408504143459512988472140877, 28766149925962843963097991313520446995104, -44617545137068682095219216378532873549081, 6252364735581546483974416983185307999790, -9441898006372648511470871875245573456949, 999333168700010265124529118214866265700, -974547604338917276804648297164716494788, 43086474856755786736806948974458150426, -101766573347334460595769573313095897097, 23922323705038155285808534027895547870, -16838637736554230981773494760223464879], 62248249974122381323764740797412088182272], [[-54402281107066386012128128500711781146752, 140189395440064831520681915701571437230280, -202781620579017311000384799547209577525613, 225309376627003704562124052130136480196960, -223025920969569451865639865805244103852349, 190191431361327719497712930732276701480552, -105377181055344899686589091144296909029070, 61742032607094963789568469523537611002276, -38849035333921343359432566686145173642047, 30974846783514754999884023334988943752826, -16086429631735626679342876149714919580883, 11197003176848895375880718562630446914508, -3549996226960596287544721418726993787779, 2269065359886643509124379920606992756086, -437923897281047979568402181322678141492, 216755493913912320648291906561521425798, -32873279192500293490544639841712050071, 28032504820860547132112555275068670652, -9147814168747263654124320414403415617, 3544978268046543062999516505698643646], 7781031246765297665470592599676511022784], [[48073377799957110507004021648609604432128, -136286603376513034519928765797349954292784, 211089315348199919347444689616437550974542, -279802349810655543645469500331185951597049, 196938794427826705818363507541791443925488, -246893950756649488032617871257934814870893, 126241732685217130505896875759424308956126, -94904575020448181330419463779272804253106, 28834104622376883248948906702640602587450, -50406459058020709929567425444411670921071, 10892468379833224729815313655305128786106, -19874072647339466069661099297032807116479, 2427668834933916760177843493256847658604, -4123820281138485902212831412057209320847, 401091903340044932174559539464597653300, -425850789661439743564270399667153052272, 16062269273566598029247949023949990424, -44712770917040098107596741091157909167, 9848956513035299333774993158552568768, -7226042512529813687977136301087880357], 15562062493530595330941185199353022045568], [[-16378698747273597161622109717055800100352, 178756364931676401795104338623035505410496, -468958110742500441094445101560149555391880, 1050261148860923765396517104732836244333607, -476555246085641966566871078033771520895046, 1034344584398038099216614966450854248408995, -471890141939991462789981814798570414443174, 441806102750691655645915003891649131428294, -38897794641971912017410169835295879844888, 246568739344000097625985984793169903064477, -10870658483953881071038033563505659507056, 103790888687576024115906709898123284807049, -2957878006521143168301457348299178639518, 21929681707764681471944642885354859133701, -1132653229802264927550837659284301428324, 2337632845951024171959932192007566045284, 23785421824934906550039668877905411318, 222194473242664732851474430140332162809, -35978568659761914150932584833866798446, 40596782805359312761800554215989078367], 62248249974122381323764740797412088182272], [[-41326985811475877958956665414284504334592, 134403494423875459683083207733958116312496, -228614643812936823215573957252553693436030, 357727517717958964790764260303051341755373, -194983061775940641899436285815056776441608, 328927670816321956769001018775959777859889, -159695595470176887739051859356556019645318, 138030289209929340526408284666936273225274, -23369487513390444537663043449863434771978, 74951528099864463442453968404455848847563, -7548249876058019029509622568315644133546, 30702724256726027809469751546689094570699, -1699088623652641359580611648934207767748, 6435729592557742076141297994105379518539, -416566093147068661798434223857226935012, 683203466176498724238508792259530018496, -2820947590776240795702147728308291904, 66304915158852482440872055251757429819, -11789598286898351339393048650651729976, 11738334053384818868022567163828891289], 15562062493530595330941185199353022045568], [[-93176162792738704664831830392552199398400, 467693768916983998044907527018420509670272, -1093786241774581333237728386667340957270968, 1393415308490059882310775804418867357109059, -1107289524792049625625504324202113411405550, 1463505744963292337032452608484459130494319, -804580278783787865368100593936509919014942, 521947283499967035868026598946772100508254, -189309902532666468687041732520911452462248, 284652869061347426614604919220908602014641, -75056915135863941225794150912074087750688, 120213150348498205256212109227614140073965, -16751423916311498389555046139074202269446, 25964307343022252197542246905442988915641, -2768185091077611586986420891331455005108, 2679963964794934962637898766179985585044, -102112795699821852744276565699991304674, 276074954321875366495364126366810546589, -67204281675684342191519300929997053302, 47185056231610516422003050538572183931], 62248249974122381323764740797412088182272], [[-33965259329723513932761113985854488648192, 614463348164989157863294685592027354839168, -1428601150085950420615641757639451252481928, 1781327752784537188139985181082079458215237, -1354111369493546541057924623161536979991522, 1793178216796989702505180499356997534328377, -954245889440647494449289638864374763245874, 635210152470246834000903783303376156485362, -241125478802834791618037553819245787175960, 340457210425084225236595315518149340188071, -96866941579099983806925670601301989158112, 141619028816139394142766365272097593074187, -21365637993119425355290664919536000185866, 30396906160244495211130636297488595795807, -3404187050014043721975402018581866108972, 3129816379819480713022752477396019235148, -142502989942834164536037329368017593550, 326253227038577618950485236648424398555, -81178117846018986025617888858783058202, 54745077087405859333120143448953693261], 62248249974122381323764740797412088182272]]

hecke_ring_character_values = [[575, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [165, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [129, [0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1, 0, -1, -1, 0, 1, 0, -1, 0, -1, 0, 0, 0, 0, 0], [0, 0, 1, 1, -1, -1, 2, 0, 0, 0, 1, 0, 0, -1, -1, 0, 1, -1, -1, 0], [0, 0, 1, 0, 1, 0, 0, 1, 0, -1, -1, 1, -1, 0, 0, -1, 0, 1, -1, 0], [0, 1, 0, 0, 1, -1, 0, 0, -1, 0, 0, -1, 0, 1, 0, 0, 1, 0, 0, 0], [2, 0, -1, -2, 2, 0, -2, -2, 1, 0, 0, -2, -2, 0, 0, 0, 0, 0, 1, -1], [1, -1, 1, 0, 0, 1, -1, 2, 1, -1, 0, 0, 0, 0, 0, -1, 0, 0, -1, 0], [0, -2, -1, 0, -1, 0, 1, 0, 1, 1, 0, 1, 1, -1, 0, 1, 3, -1, -2, -1], [0, -1, -1, -1, 0, 1, -1, -2, 0, 0, -1, 0, 0, 0, 1, 0, 0, 0, 0, -1], [2, -1, -1, 1, -2, -1, 1, -3, 0, 1, 1, 0, -2, -1, -1, 2, 1, -1, 0, 1], [3, -1, 0, 1, 0, 0, 0, -3, -1, 0, 0, 0, -2, -2, -2, 0, 0, 0, 0, 1], [-2, -1, 2, 1, -1, 0, -1, 2, 0, 0, 0, 1, 1, 2, 2, -1, -1, 0, -1, 0], [0, -1, -1, 1, 0, 1, -1, -2, -1, 2, 1, 0, 0, 0, 1, 1, 0, 0, 1, -1], [1, -1, 0, 0, -2, 0, -1, -1, 2, 0, 0, 2, 0, 1, 1, -1, -1, 0, 1, -2], [1, 2, 0, 0, 2, -1, -1, 0, -2, 0, 0, -1, -1, 2, 0, -2, -1, 0, 0, 0], [2, -2, 3, 0, -3, 2, -1, -1, 1, 0, 0, 0, 0, 0, -1, -1, 0, 0, -1, 1], [0, 1, -1, 0, -1, -2, 0, -3, -1, 1, 1, -2, -2, -1, -2, 1, 1, -1, 0, -1], [0, 0, -2, -1, 0, 1, -1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, -1, -1], [2, 0, 2, 1, 0, -1, 1, -1, 0, 0, 0, 1, -1, -2, 0, 0, -1, -1, 0, 1], [0, 0, -2, -1, 3, -2, -1, 1, 0, 0, 0, -4, 1, 1, 0, 0, 1, 1, 1, 1], [-2, -2, 0, 0, -2, 3, 5, 0, -1, 0, 0, 3, 2, 1, -1, -1, -2, 0, 0, 0], [-2, 1, 0, 1, 3, -1, 3, 2, -3, -1, 1, 0, 0, 0, -1, 1, 0, 0, 1, 1], [1, -2, 0, -1, -1, 1, 2, 0, 0, -1, 0, 1, -1, 0, -2, -1, -3, 2, 0, 0], [0, 3, 0, 0, 3, -4, 4, 0, -1, 0, 0, -4, 0, 1, 1, 2, 1, -1, 0, 0], [-1, 1, 0, 1, 0, 2, -2, 0, 0, 1, 0, 2, 1, 0, -1, 1, -1, 1, 0, 0], [0, 0, 1, 1, -4, 3, 1, -1, 0, 0, 0, 3, -1, -1, 0, 0, 0, -1, 0, 0], [0, 0, -1, 0, -1, 4, -2, -1, 4, 1, -2, -1, -1, -2, 2, 1, 1, -1, 0, -2], [-3, 1, 1, 1, -1, -1, 1, 7, 1, 1, 1, 0, 0, 0, 2, -3, 0, 0, -3, -2], [0, 3, -3, 0, 0, -1, -1, -2, -3, 0, 0, -3, 3, 2, -1, 3, -2, 0, 2, 2], [3, 0, 2, 2, 0, -3, 2, 3, 0, 1, 1, -1, 3, 1, 0, 0, 0, -2, 3, 0], [-3, -4, 0, -2, -2, 4, 6, 0, 1, -2, 0, 4, 3, -1, 0, -3, -2, 2, 0, 0], [3, 2, -1, 0, 1, -2, -1, 3, -1, 0, 0, 0, 0, 0, -2, -2, 0, 0, -2, 2], [3, -6, 0, -1, -1, 0, -5, -3, 2, 0, 0, 1, -3, 2, 2, 0, 0, 0, 0, -2], [5, -4, 0, -1, -3, -3, 0, 0, 1, -1, 0, -3, -5, -1, -2, -1, 3, 1, 0, 0], [3, 0, -2, 0, 2, -2, 0, 0, 0, 0, 0, -1, 0, 2, 0, 0, 2, 0, 3, 1], [4, 0, -1, -1, -5, 5, -1, 2, 0, 1, 1, 0, 2, 2, 0, 0, 0, 1, -2, 1], [6, 0, 1, -2, 0, 4, -2, -6, 0, -2, -2, -4, -6, 1, 0, 0, -3, 2, 2, 1], [-1, 1, -4, 2, -3, -1, -1, -1, 1, 3, 2, 0, 0, 0, 2, 2, 0, 0, 2, -2], [0, 0, 2, 0, -3, 0, 2, -2, 1, 3, 2, -3, -11, -2, -1, -2, 1, -3, 2, -2], [-5, 0, -3, -2, 0, 3, -2, -3, 0, -1, -1, -1, -3, 0, 0, 0, 1, 2, 1, -1], [5, -3, 2, 0, 3, 3, -4, 5, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 1], [0, 2, 0, 0, 1, -3, 7, 5, -2, -1, 0, -1, 7, -1, -3, 0, -1, 1, 0, -1], [-3, 1, 2, 0, 0, -2, -4, 3, -2, 0, 2, -2, -6, 0, 0, 0, 2, -2, -2, 2], [6, -4, -6, -3, 0, 1, 3, -6, 0, 0, -1, 1, 1, -3, -3, 5, 4, 1, 1, 0], [9, 0, 2, -1, -3, 0, -3, -9, 2, 0, 0, 3, -5, -2, -2, 0, 0, 0, -2, -2], [7, 1, 0, 1, 0, 1, 2, 0, 2, 1, 0, 1, -7, -2, -1, 2, 3, -4, 0, 0], [0, 1, 0, 0, 2, -6, -7, -5, 0, -2, 1, 1, -3, 0, 0, 0, -1, 2, -1, 0], [-2, 1, -1, -3, 1, 0, -6, 2, 0, 0, 0, -1, -6, 0, 0, 0, 0, 0, 1, 0], [-3, -2, 0, -1, -1, 1, 8, 0, -2, -1, 0, 1, 3, 2, -2, -4, -3, 1, 0, 0], [2, 7, 3, 2, 2, -7, -4, -6, -1, 2, 2, 0, 0, 0, 2, -3, 0, 0, -3, -2], [-5, -3, -1, 1, -4, 3, 6, 10, -3, -1, 1, 0, 0, 0, -1, 1, 0, 0, 1, 1], [0, -2, -1, 0, 0, 5, 5, 5, 0, 0, -3, 2, 10, 0, 0, 1, -1, 0, 1, 0], [0, 6, 1, 0, -1, -2, -3, -2, 5, 1, 0, -7, 3, -3, 2, -1, 1, -1, 0, -3], [0, -4, -2, 0, -4, 2, -4, 0, -2, 0, -2, 6, -2, 0, 0, 1, -1, 2, 1, 2], [4, 0, 0, -2, 2, 2, -4, 0, 0, -2, 0, 2, -4, 0, 2, -1, 3, -2, 0, 0], [0, 5, 1, 0, 1, -3, -4, -6, -3, -1, 5, -4, -8, 0, -3, -1, 2, 1, -3, 0], [-2, 7, 0, -1, 2, -2, 5, 2, -4, 0, 2, -4, 3, 0, 0, 1, 3, -2, -1, 4], [7, 4, 5, 1, 4, -4, -8, 2, -1, -1, 1, 0, 0, 0, 1, -3, 0, 0, -3, -1], [-10, 0, -6, -5, 2, 1, 0, 10, 4, 0, -1, -1, 5, 4, 4, 2, 1, 1, 4, -4], [-10, -3, 0, 1, -4, 3, 10, 0, 3, 1, 0, 3, 10, -3, -1, -2, 2, -2, 0, 0], [0, -1, -2, 0, 0, 1, -1, 2, 6, 0, -1, 1, 9, -3, 3, 2, 0, 0, 0, -3], [9, 6, -3, 0, 4, -6, -9, -2, -1, -1, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0], [0, 2, 1, 0, 0, -6, 9, 6, 0, 0, 2, -2, -2, -3, -3, -1, 5, 0, -5, -3], [8, 0, 0, 3, -3, 1, 3, -2, 0, -1, -1, 5, -2, -4, 0, 0, 3, -3, 5, 0], [4, 0, 0, 2, -3, 0, 2, -10, 0, 1, 1, 1, -10, -2, 0, 0, 2, -2, 0, -5], [10, 0, 0, 2, -2, -3, -1, 0, 6, 2, 0, -3, -10, -6, 1, -2, 0, -4, 0, 0], [-2, 3, 0, -2, 5, 4, -7, 0, -1, -2, 0, 4, 2, 1, 2, 2, 0, 0, 0, 0], [5, -7, 0, -2, -5, 2, 4, 0, -1, -2, 0, 2, -5, 1, -5, -3, 2, -1, 0, 0], [0, 3, 5, 0, 3, -2, 1, 3, -2, -3, 3, 0, 12, 1, -1, -5, -2, 3, -1, 1], [-5, -2, 6, 2, -2, -3, 10, 5, 1, 0, 3, -1, 5, -2, -2, 3, 6, -3, -9, -1], [5, 2, 4, 0, 3, -2, -9, -3, 1, -1, 0, 0, 0, 0, 4, -4, 0, 0, -4, -4], [0, 0, -1, 0, 1, 1, -2, 0, -3, -1, 0, 1, 8, 4, 1, 1, -1, 1, 0, 4], [4, 0, 1, 0, 1, -1, 0, -3, 0, 0, 0, -3, -3, 5, 0, 0, -1, 0, 1, 1], [6, 5, 0, -2, 7, -2, -8, 0, 1, -2, 0, -2, -6, -1, 1, -2, -5, 1, 0, 0], [2, -5, 2, 5, -3, 0, 3, -2, -2, 0, 0, 3, -3, -6, -6, 3, 3, 0, -5, 2], [2, 0, 6, -2, 4, 0, -2, 1, 0, -2, -2, 2, 1, 2, 0, 0, -8, 2, 1, 2], [0, 0, 0, 0, -4, 2, 0, -13, 0, 2, 2, 2, -13, -5, 0, 0, 0, 0, 6, -4], [-11, 0, 2, 3, -6, 1, 3, 8, 0, 2, 2, 3, 8, -1, 0, 0, 1, -3, -3, -4], [0, -5, -2, 0, 0, -2, 6, 4, -3, 0, -2, 5, -1, 1, -2, 2, 2, 0, -2, 1], [2, 8, 0, 1, 7, -2, 1, 0, 1, 1, 0, -2, -2, -1, 0, -1, 1, 2, 0, 0], [-5, 3, 6, 4, 0, 1, -3, 5, 3, 0, -1, 1, -1, 1, 1, 0, -1, 1, -6, -3], [-3, -4, -4, -3, 2, 4, -4, -8, 8, 4, -3, 0, 0, 0, 7, -2, 0, 0, -2, -7], [0, 3, -2, 0, -2, 0, -1, -2, 3, 2, 3, -5, -4, -2, 1, 2, 3, -2, -1, -2], [4, -6, 1, 0, -4, -1, -2, -4, 2, 0, 1, 3, -1, 2, 2, -3, -2, -1, 2, -2], [-15, -6, 2, 1, -6, -2, 11, 15, -4, 0, 2, 4, 9, 0, 0, 0, 2, -2, -2, 4], [0, -2, 1, 0, -1, 4, -10, -9, 6, 1, -1, 1, -5, -4, 2, -1, 2, -1, -1, -4], [2, -3, -7, -2, 5, 3, 0, 5, 1, -3, -2, 0, 0, 0, -2, 4, 0, 0, 4, 2], [-6, -3, 0, 3, -6, -3, 19, 0, 0, 3, 0, -3, 6, 0, 3, 2, 1, -5, 0, 0], [7, 4, -5, 3, 0, 0, 0, -7, -6, 0, 0, 0, 2, 2, 2, 5, 5, 0, 0, 6], [-11, 4, 0, 3, -2, -4, 9, 20, 0, 5, 3, 0, 0, 0, 2, 1, 0, 0, 1, -2], [7, 0, -1, -1, 1, -1, -1, -6, 0, 1, 1, -1, -6, 0, 0, 0, 0, 1, -1, -4], [-5, 1, 0, -1, 2, 2, -10, 0, -1, -1, 0, 2, 5, 1, 1, -3, -3, 2, 0, 0], [0, -2, 1, 0, 0, 1, -8, -11, -1, 0, -2, 2, -14, -2, -3, -1, -3, 0, 3, -2], [0, 5, 2, 0, 0, -1, -2, -6, -3, 0, 1, -5, -25, -1, -4, -2, -3, 0, 3, -1], [10, 2, -7, 1, 4, -2, -4, 2, -5, -1, 1, 0, 0, 0, -6, 4, 0, 0, 4, 6], [0, -1, -2, 0, -2, -2, -8, -8, 1, 2, 3, -1, 5, 1, 2, 2, -3, -2, 5, 1], [0, 2, 2, 0, 0, -3, -8, -2, 4, 0, -3, -2, 2, 2, 6, -2, 0, 0, 0, 2], [9, 0, 5, -1, -1, 5, -1, -3, 0, -3, -3, -2, -3, -3, 0, 0, -6, 1, 5, 4], [0, 1, -2, 0, 1, 6, -10, -6, 4, -1, -4, 0, -2, -1, 3, 2, -2, 1, 1, -1], [0, 1, -1, 0, 1, -3, 0, 2, 3, -1, 4, 0, -8, -2, 1, 1, -1, 1, 0, -2], [-4, 9, -7, -1, 9, -9, -3, 3, 4, 3, -1, 0, 0, 0, 7, 5, 0, 0, 5, -7], [-4, 0, 1, 2, -3, 1, 2, 7, 0, 0, 0, 0, 7, 4, 0, 0, 1, -2, -4, 3], [-13, 0, 3, 1, -4, 8, 1, 16, 0, -5, -5, 7, 16, -1, 0, 0, -2, -1, 0, 6], [2, 2, 7, -1, 1, 1, -9, -2, 1, 0, -1, 0, -11, -3, -3, 0, -1, 1, -7, -1], [3, 1, 0, -5, 6, 0, 3, 0, 1, -5, 0, 0, -3, -1, -3, 1, 0, 4, 0, 0], [-1, -10, 0, 3, -13, 9, 1, 0, -2, 3, 0, 9, 1, 2, -5, 4, 0, 0, 0, 0], [-13, 0, -1, 2, -6, -2, 2, -4, 0, 6, 6, -5, -4, 0, 0, 0, 3, -2, -2, -4], [0, 9, 4, 0, 0, -7, 4, 6, 3, 0, 3, -9, 5, -1, 2, -4, 3, 0, -3, -1], [-10, -3, 7, 2, -5, -1, 15, 10, -1, 0, 1, 4, 6, -8, -8, -5, -4, -1, -2, 1], [-11, -11, -6, -1, -1, 3, 3, 11, 0, 0, -3, 4, 11, 5, 5, 0, -3, 3, 6, 0], [-7, -5, -1, -2, -3, 5, 10, 21, 1, 1, -2, 0, 0, 0, -3, 5, 0, 0, 5, 3], [-12, 4, 0, -2, 6, -8, 10, 0, 0, -2, 0, -8, 12, 0, 2, 0, 1, -1, 0, 0], [4, 10, 5, 4, -1, -10, -7, 4, -1, 3, 4, 0, 0, 0, 3, -4, 0, 0, -4, -3], [14, -1, -7, 0, 0, 1, -15, -14, 0, 0, -1, 1, -17, -3, -3, 2, 1, 1, 5, 0], [-1, 0, 0, -2, 2, 2, -2, -19, 0, -2, -2, -1, -19, 0, 0, 0, -2, 2, 4, 3], [-14, 0, 3, -2, 4, -2, -2, 4, 0, 0, 0, 4, 4, 5, 0, 0, -5, 2, -2, -3], [9, 0, -1, -1, 4, -3, -1, 8, 0, 0, 0, 2, 8, 0, 0, 0, 0, 1, -5, -1], [4, -4, -7, -2, 12, 4, -5, -8, 4, -1, -2, 0, 0, 0, 1, 5, 0, 0, 5, -1], [0, -1, -7, 0, -3, -2, -5, -3, 4, 3, 0, -2, -12, 1, 5, 7, -3, -3, 6, 1], [-2, 4, 0, -2, 6, 0, -1, 0, 3, -2, 0, 0, 2, -3, -1, -2, -2, 1, 0, 0], [-4, 0, 9, 2, -4, 0, 2, 1, 0, 2, 2, 2, 1, -2, 0, 0, -7, -2, 0, 5], [-2, -1, 2, 2, -2, 2, -7, 2, -2, 0, -2, 4, -6, -1, -1, 0, -2, 2, -2, 2], [9, 5, -3, -2, 0, -5, -4, 4, 0, -2, -2, 0, 0, 0, -5, -1, 0, 0, -1, 5], [1, 3, -10, -1, -1, -3, 0, 1, -5, -1, -1, 0, 0, 0, -1, 2, 0, 0, 2, 1], [18, -4, 0, 1, -5, 0, -4, 0, 5, 1, 0, 0, -18, -5, -1, 5, 8, -5, 0, 0], [0, -12, 3, 0, 1, 11, -6, -1, 4, -1, -6, 13, 7, 0, 4, -3, -7, 1, 6, 0], [8, -2, -4, 3, -9, 2, 0, -11, -9, 5, 3, 0, 0, 0, -8, 1, 0, 0, 1, 8], [-13, 0, -1, 6, -13, -1, 6, 1, 0, 8, 8, 0, 1, -4, 0, 0, 7, -6, -5, 0], [-14, 1, 4, 2, -11, -1, 19, 3, -9, 3, 2, 0, 0, 0, -5, -1, 0, 0, -1, 5], [-14, 10, -2, 2, 4, 2, -1, 14, -4, 0, -2, -2, 8, 7, 7, 0, -2, 2, 2, 4], [15, 14, 0, 0, 14, -7, -7, 0, 5, 0, 0, -7, -15, -5, 4, -8, 3, 1, 0, 0], [2, 2, -10, -6, 10, 2, -10, -2, -2, 0, -2, -8, -4, 4, 4, 7, 5, 2, 3, 2], [0, -1, -4, 0, -1, -1, -3, -12, -7, 1, 2, 0, -4, -1, -8, 4, 3, -1, -2, -1], [2, -7, -13, -6, 1, 5, -5, -2, 3, 0, -5, 4, -2, -2, -2, 11, 6, 5, 2, -3], [0, 1, -2, 0, 6, 3, 4, 9, -8, -6, -7, 5, 12, 7, -1, 2, -7, 6, 1, 7], [-6, -7, 2, 3, -5, -4, 23, 6, -4, 0, 4, 1, 13, -6, -6, -1, 3, -4, -1, 4], [0, 0, 1, 0, -6, 6, -3, -2, 2, 6, 1, -6, 0, 5, 7, -1, 2, -6, 4, 5], [-17, 0, -8, -1, -7, 5, -1, -2, 0, 3, 3, -3, -2, 1, 0, 0, 7, 1, 1, -9], [-11, 0, -6, -4, 9, -4, -4, -8, 0, -1, -1, -12, -8, -2, 0, 0, 2, 4, -1, -2], [-17, 0, 7, 2, 9, -10, 2, 8, 0, -1, -1, 4, 8, 3, 0, 0, -5, -2, -5, -3], [3, -11, 0, 0, -11, 8, -1, 0, 3, 0, 0, 8, -3, -3, 0, 1, 7, -4, 0, 0], [5, 0, -4, 0, -3, 4, 0, -6, 0, -1, -1, -8, -6, 5, 0, 0, 4, 0, -2, -4], [4, -6, 0, -5, -1, 4, -6, 0, -2, -5, 0, 4, -4, 2, -3, 4, -6, 7, 0, 0], [0, 8, 1, 0, 4, -2, 7, 12, -4, -4, 2, -4, 4, 5, 1, -1, 3, 4, -7, 5], [-1, 1, 6, -3, 12, -1, -4, -3, 9, -3, -3, 0, 0, 0, 5, 0, 0, 0, 0, -5], [4, -2, -6, -11, 9, 5, -15, -4, 4, 0, -5, -4, -11, -1, -1, -3, -8, 5, 9, -4], [-1, 1, -4, -1, 1, 7, -7, 1, -1, 0, -7, 6, 8, 8, 8, 1, -6, 7, 3, 1], [8, 0, 0, -3, 3, 2, -5, 0, -4, -3, 0, 2, -8, 4, -8, 2, -9, 8, 0, 0], [5, -2, 0, 2, -4, 0, 5, 0, 0, 2, 0, 0, -5, 0, -6, 0, 7, -8, 0, 0], [-5, 3, 0, 0, 3, 2, -15, 0, -2, 0, 0, 2, 5, 2, -4, 0, -3, 0, 0, 0], [12, 1, 4, -3, 8, -1, -15, -6, 8, -3, -3, 0, 0, 0, 3, 0, 0, 0, 0, -3], [-6, 0, 4, 3, 2, 0, 11, 19, -2, 0, 3, 0, 0, 0, -5, -1, 0, 0, -1, 5], [9, 0, -8, 1, -3, 2, 1, 7, 0, 0, 0, 3, 7, 1, 0, 0, 9, -1, 0, 2], [0, 3, -3, 0, -2, 1, -19, -18, -3, 2, 3, -5, -11, 6, 3, 3, -7, -2, 9, 6], [5, 0, 3, 4, -1, -2, 4, -8, 0, -1, -1, -8, -8, -2, 0, 0, 1, -4, 0, 7], [2, -3, 6, 3, 0, 2, 11, -2, -1, 0, -2, 2, 10, -3, -3, -6, -8, 2, 0, 1], [9, -3, -6, 0, 1, 0, 4, -9, 9, 0, 0, -1, 1, -3, -3, 5, 5, 0, 1, -9], [4, 4, 7, 4, 3, -4, -6, 16, -2, 0, 4, 0, 0, 0, 2, -8, 0, 0, -8, -2], [0, -5, 0, 0, 3, 2, -14, -15, -7, -3, -2, 8, 1, 3, -4, 0, 0, 3, -3, 3], [0, -8, -5, 0, -2, -3, -11, -11, 2, 2, 2, 6, 4, 0, 2, 5, 0, -2, 2, 0], [6, 5, 8, -4, 1, -1, -15, -6, 3, 0, 1, -2, -19, -3, -3, -7, -6, -1, -1, -3], [15, -12, 0, 0, -12, 10, 8, 0, -1, 0, 0, 10, -15, 1, -4, 1, 2, 0, 0, 0], [18, 0, -4, -2, 9, -3, -2, -19, 0, -4, -4, 3, -19, -1, 0, 0, 2, 2, -6, -8], [-12, 1, 0, -1, 2, 0, -8, 0, -6, -1, 0, 0, 12, 6, 6, 1, -8, -3, 0, 0], [-4, -8, -4, -9, 5, 9, -6, 4, 7, 0, -9, 4, 8, 5, 5, 1, -8, 9, 3, -7]]
